OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Tasks" : "Tarefas",
    "Personal" : "Persoal",
    "{actor} created calendar {calendar}" : "{actor} creou o calendario {calendar}",
    "You created calendar {calendar}" : "Creou o calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminou o calendario {calendar}",
    "You deleted calendar {calendar}" : "Eliminou o calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizou o calendario {calendar}",
    "You updated calendar {calendar}" : "Vde. actualizou o calendario {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} restaurou o calendario {calendar}",
    "You restored calendar {calendar}" : "Vde. restaurou o calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Vde. compartiu o calendario {calendar} como ligazón pública",
    "You removed public link for calendar {calendar}" : "Vde. retirou a ligazón pública do calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartiu o calendario {calendar} con Vde.",
    "You shared calendar {calendar} with {user}" : "Vde. compartiu o calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartiu o calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} deixou de compartir o calendario {calendar} de Vde.",
    "You unshared calendar {calendar} from {user}" : "Vde. deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} deixou de compartir o seu propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Vde. compartiu o calendario {calendar} co grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartiu o calendario {calendar} co grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Vde. deixou de compartir o calendario {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} deixou de compartir o calendario {calendar} do grupo {group}",
    "Untitled event" : "Evento sen título",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creou o evento {event} no calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Vde. creou o evento {event} no calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminou o evento {event} do calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vde. eliminou o evento {event} do calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizou o evento {event} no calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vde. actualizou o evento {event} no calendario {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moveu o evento {event} do calendario {sourceCalendar} ao calendario {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Moveu o evento {event} do calendario {sourceCalendar} ao calendario {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {event} do calendario {calendar}",
    "You restored event {event} of calendar {calendar}" : "Restaurou o evento {event} do calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} creou a tarefa pendente {todo} na lista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Creou a tarefa pendente {todo} na lista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} eliminou a tarefa pendente {todo} da lista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Eliminou a tarefa pendente {todo} da lista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} actualizou a tarefa pendente {todo} na lista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Actualizou a tarefa pendente {todo} na lista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} resolveu a tarefa pendente {todo} na lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Resolveu a tarefa pendente {todo} na lista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reabriu a tarefa pendente {todo} na lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Reabriu a tarefa pendente {todo} na lista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} moveu a tarefa pendente {todo} da lista {sourceCalendar} á lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Moveu a tarefa pendente {todo} da lista {sourceCalendar} á lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendario, contactos e tarefas",
    "A <strong>calendar</strong> was modified" : "Foi modificado un <strong>calendario</strong>",
    "A calendar <strong>event</strong> was modified" : "Foi modificado un <strong>evento</strong> do calendario",
    "A calendar <strong>to-do</strong> was modified" : "Modificouse unha <strong>tarefa pendente</strong> do calendario",
    "Contact birthdays" : "Aniversario do contacto",
    "Death of %s" : "Falecemento de %s",
    "Untitled calendar" : "Calendario sen título",
    "Calendar:" : "Calendario:",
    "Date:" : "Data:",
    "Where:" : "Onde:",
    "Description:" : "Descrición:",
    "_%n year_::_%n years_" : ["%n ano","%n anos"],
    "_%n month_::_%n months_" : ["%n mes","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (hai %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrición: %s",
    "Where: %s" : "Onde: %s",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "In a %1$s on %2$s for the entire day" : "Nun/ha %1$s o %2$s durante todo o día",
    "In a %1$s on %2$s between %3$s - %4$s" : "Nun/ha %1$s o %2$s entre %3$s e %4$s",
    "In %1$s %2$s on %3$s for the entire day" : "En %1$s %2$s o %3$s durante todo o día",
    "In %1$s %2$s on %3$s between %4$s - %5$s" : "En %1$s %2$s o %3$s entre %4$s e %5$s",
    "Could not generate when statement" : "Non foi posíbel xerar a declaración when (cando)",
    "Every Day for the entire day" : "Todos os días durante todo o día",
    "Every Day for the entire day until %1$s" : "Todos os días durante todo o día ata o %1$s",
    "Every Day between %1$s - %2$s" : "Todos os días entre %1$s e %2$s",
    "Every Day between %1$s - %2$s until %3$s" : " Todos os días entre %1$s e %2$s ata o %3$s",
    "Every %1$d Days for the entire day" : "Cada %1$d días durante todo o día",
    "Every %1$d Days for the entire day until %2$s" : "Cada %1$d días durante todo o día ata o %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Cada %1$d días entre %2$s e %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Cada %1$d días entre %2$s e %3$s ata o %4$s",
    "Could not generate event recurrence statement" : "Non foi posíbel xerar a declaración de recorrencia do evento",
    "Every Week on %1$s for the entire day" : "Todas as semanas o %1$s durante todo o día",
    "Every Week on %1$s for the entire day until %2$s" : "Todas as semanas o %1$s durante todo o día ata o %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Todas as semanas o %1$s entre %2$s e %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Todas as semanas o %1$s entre %2$s e %3$s ata o %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Cada %1$d semanas o %2$s durante todo o día",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Cada %1$d semanas o %2$s durante todo o día ata o %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Cada %1$d semanas o %2$s entre %3$s e %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Cada %1$d semanas o %2$s entre %3$s e %4$s ata o %5$s",
    "Every Month on the %1$s for the entire day" : "Todos os meses o %1$s durante todo o día",
    "Every Month on the %1$s for the entire day until %2$s" : "Todos os meses o %1$s durante todo o día ata o %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Todos os meses o %1$s entre %2$s e %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Todos os meses o %1$s entre %2$s e %3$s ata o %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Cada %1$d meses o %2$s durante todo o día",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Cada %1$d meses o %2$s durante todo o día ata o %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Cada %1$d meses o %2$s entre %3$s e %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Cada %1$d meses o %2$s entre %3$s e %4$s ata o %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Todos os anos en %1$s, o %2$s durante todo o día",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Todos os anos en %1$s, o %2$s durante todo o día ata o %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Todos os anos en %1$s, o %2$s entre %3$s e %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Todos os anos en %1$s, o %2$s entre %3$s e %4$s ata o %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Cada %1$d anos en %2$s, o %3$s durante todo o día",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Cada %1$d anos en %2$s, o %3$s durante todo o día ata o %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Cada %1$d anos en %2$s, o %3$s entre %4$s e %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Cada %1$d anos en %2$s, o %3$s entre %4$s e %5$s ata o %6$s",
    "On specific dates for the entire day until %1$s" : "En datas concretas durante todo o día ata o %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "En datas concretas entre %1$s e %2$s ata o %3$s",
    "In a %1$s on %2$s" : "Nun/ha %1$s o %2$s",
    "In a %1$s on %2$s then on %3$s" : "Nun/ha %1$s o %2$s após o %3$s",
    "In a %1$s on %2$s then on %3$s and %4$s" : "Nun/ha %1$s o %2$s após o %3$s e o %4$s",
    "In %1$s %2$s on %3$s" : "En %1$s %2$s o %3$s",
    "In %1$s %2$s on %3$s then on %4$s" : "En %1$s %2$s o %3$s, após o %4$s",
    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "En %1$s %2$s o %3$s, após o %4$s e o %5$s",
    "Could not generate next recurrence statement" : "Non foi posíbel xerar a seguinte declaración de recorrencia",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "\"%1$s\" has been canceled" : "Cancelouse «%1$s»",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s aceptou o seu convite",
    "%1$s has tentatively accepted your invitation" : "%1$s aceptou provisionalmente o seu convite",
    "%1$s has declined your invitation" : "%1$s declinou o seu convite",
    "%1$s has responded to your invitation" : "%1$s respondeu ao seu convite",
    "Invitation updated: %1$s" : "Convite actualizado: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s actualizou o evento «%2$s»",
    "Invitation: %1$s" : "Convite: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s quere convidalo a «%2$s»",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Title:" : "Título:",
    "When:" : "Cando:",
    "Location:" : "Lugar:",
    "Link:" : "Ligazón:",
    "Occurring:" : "Acaecendo:",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "More options …" : "Máis opcións…",
    "More options at %s" : "Máis opcións en %s",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sunday" : "domingo",
    "January" : "xaneiro",
    "February" : "febreiro",
    "March" : "marzo",
    "April" : "abril",
    "May" : "maio",
    "June" : "xuño",
    "July" : "xullo",
    "August" : "agosto",
    "September" : "setembro",
    "October" : "outubro",
    "November" : "novembro",
    "December" : "decembro",
    "First" : "Primeiro",
    "Second" : "Segundo",
    "Third" : "Terceiro",
    "Fourth" : "Cuarto",
    "Fifty" : "Quinto",
    "Last" : "Último",
    "Second Last" : "Penúltimo",
    "Third Last" : "Antepenúltimo",
    "Fourth Last" : "Trasantepenúltimo",
    "Fifty Last" : "Quinto dende o final",
    "Contacts" : "Contactos",
    "{actor} created address book {addressbook}" : "{actor} creou o caderno de enderezos {addressbook}",
    "You created address book {addressbook}" : "Vde. creou o caderno de enderezos {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} eliminou o caderno de enderezos {addressbook}",
    "You deleted address book {addressbook}" : "Vde. eliminou o caderno de enderezos {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} actualizou o caderno de enderezos {addressbook}",
    "You updated address book {addressbook}" : "Vde. actualizou o caderno de enderezos {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} compartiu o caderno de enderezos {addressbook} con Vde.",
    "You shared address book {addressbook} with {user}" : "Vde. compartiu o caderno de enderezos {addressbook} con {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} compartiu o caderno de enderezos {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} deixou de compartir o seu caderno de enderezos {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Vde. deixou de compartir o caderno de enderezos {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} deixou de compartir o caderno de enderezos {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} deixaron de compartir o seu caderno de enderezos {addressbook}",
    "You shared address book {addressbook} with group {group}" : "Vde. compartiu o caderno de enderezos {addressbook} co grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} compartiu o caderno de enderezos {addressbook} co grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "Vde. deixou de compartir o caderno de enderezos {addressbook} do grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} deixou de compartir o caderno de enderezos {addressbook} do grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} creou o contacto {card} no caderno  de enderezos {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Vde. creou o contacto {card} no caderno de enderezos {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} eliminou o contacto {card} do caderno de enderezos {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Vde. eliminou o contacto {card} do caderno de enderezos {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} actualizou o contacto {card} no caderno de enderezos {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Vde. actualizou o contacto {card} no caderno de enderezos {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Foi modificado un <strong>contacto</strong> ou <strong>caderno de enderezos</strong>",
    "Accounts" : "Contas",
    "System address book which holds all accounts" : "Caderno de enderezos do sistema que contén todas as contas",
    "File is not updatable: %1$s" : "Non é posíbel actualizar o ficheiro: %1$s",
    "Could not write to final file, canceled by hook" : "Non foi posíbel escribir no ficheiro final, foi cancelado polo sistema",
    "Could not write file contents" : "Non foi posíbel escribir o contido do ficheiro",
    "_%n byte_::_%n bytes_" : ["%n  byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Produciuse un erro ao copiar o ficheiro na localización de destino (copiado: %1$s, tamaño agardado do ficheiro: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Tamaño agardado do ficheiro %1$s mais lido (do cliente de Nextcloud) e escrito (no almacenamento de Nextcloud) %2$s. Pode ser un problema de rede no lado do envío ou un problema ao escribir no almacenamento no lado do servidor.",
    "Could not rename part file to final file, canceled by hook" : "Non foi posíbel cambiar o nome do ficheiro parcial ao ficheiro final,  foi cancelado polo sistema",
    "Could not rename part file to final file" : "Non foi posíbel cambiar o nome do ficheiro parcial ao ficheiro final",
    "Failed to check file size: %1$s" : "Produciuse un erro ao comprobar o tamaño do ficheiro: %1$s",
    "Could not open file" : "Non foi posíbel abrir o ficheiro",
    "Encryption not ready: %1$s" : "O cifrado non está preparado: %1$s",
    "Failed to open file: %1$s" : "Produciuse un erro ao abrir o ficheiro: %1$s",
    "Failed to unlink: %1$s" : "Produciuse un erro ao desligar: %1$s",
    "Failed to write file contents: %1$s" : "Produciuse un erro ao escribir o contido do ficheiro: %1$s",
    "File not found: %1$s" : "Non se atopou o ficheiro: %1$s",
    "Invalid target path" : "A ruta de destino non é correcta",
    "System is in maintenance mode." : "O sistema está en modo de mantemento.",
    "Upgrade needed" : "É necesario anovar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "É preciso configurar o seu %s para que empregue HTTPS para poder usar CalDAV e CardDAV con iOS / macOS.",
    "Configures a CalDAV account" : "Configurar unha conta de CalDAV",
    "Configures a CardDAV account" : "Configurar unha conta de CardDAV",
    "Events" : "Eventos",
    "Untitled task" : "Tarefa sen título",
    "Completed on %s" : "Rematado o %s",
    "Due on %s by %s" : "Caduca o %s por %s",
    "Due on %s" : "Caduca o %s",
    "DAV system address book" : "Caderno de enderezos do sistema DAV",
    "No outstanding DAV system address book sync." : "Non hai sincronización pendente do caderno de enderezos do sistema DAV.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "A sincronización do caderno de enderezos do sistema DAV aínda non foi executada aínda porque a súa instancia ten máis de 1000 usuarios ou porque se produciu un erro. Execútea manualmente con occ dav:sync-system-addressbook.",
    "WebDAV endpoint" : "Punto final WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Non foi posíbel comprobar que o seu servidor web estea configurado correctamente para permitir a sincronización de ficheiros a través de WebDAV. Compróbeo manualmente.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O servidor non foi configurado correctamente para permitir a sincronización de ficheiros, semella que a interface WebDAV non está a funcionar.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "O seu servidor web está configurado correctamente para permitir a sincronización de ficheiros a través de WebDAV.",
    "Migrated calendar (%1$s)" : "Calendario migrado (%1$s)",
    "Calendars including events, details and attendees" : "Calendarios incluíndo eventos, detalles e asistentes",
    "Contacts and groups" : "Contactos e grupos",
    "WebDAV" : "WebDAV",
    "First day" : "Primeiro día",
    "Last day (inclusive)" : "Último día (inclusive)",
    "Out of office replacement (optional)" : "Substitución fóra da oficina (opcional)",
    "Name of the replacement" : "Nome do substituto",
    "No results." : "Sen resultados",
    "Start typing." : "Comece a escribir.",
    "Short absence status" : "Estado de ausencia breve",
    "Long absence Message" : "Mensaxe de ausencia longa",
    "Save" : "Gardar",
    "Disable absence" : "Desactivar a ausencia",
    "Absence saved" : "Ausencia gardada",
    "Failed to save your absence settings" : "Produciuse un fallo ao gardar os axustes de ausencia",
    "Absence cleared" : "Limpouse a ausencia",
    "Failed to clear your absence settings" : "Produciuse un fallo ao limpar os axustes de ausencia",
    "Time zone:" : "Fuso horario:",
    "to" : "para",
    "Delete slot" : "Eliminar franxa horaria",
    "No working hours set" : "Sen horario de traballo estabelecido",
    "Add slot" : "Engadir franxa horaria",
    "Weekdays" : "Días laborábeis",
    "Pick a start time for {dayName}" : "Escolla unha hora de inicio para {dayName}",
    "Pick a end time for {dayName}" : "Escolla unha hora de finalización para {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Definir automaticamente o estado do usuario en «Non molestar» fóra de dispoñibilidade para enmudecer todas as notificacións.",
    "Failed to load availability" : "Produciuse un erro ao cargar a dispoñibilidade",
    "Saved availability" : "Dispoñibilidade gardada",
    "Failed to save availability" : "Produciuse un erro ao gardar a dispoñibilidade",
    "Availability" : "Dispoñibilidade",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Se configura o seu horario de traballo, outras persoas verán cando está fóra da oficina cando reserven unha xuntanza.",
    "Absence" : "Ausencia",
    "Configure your next absence period." : "Configurar o próximo período de ausencia.",
    "Calendar server" : "Servidor do calendario",
    "Send invitations to attendees" : "Enviar convites aos asistentes",
    "Automatically generate a birthday calendar" : "Xerar automaticamente o calendario de aniversarios",
    "Birthday calendars will be generated by a background job." : "O calendario de aniversarios xerase cun traballo en segundo plano",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por isto, non estarán dispoñíbeis inmediatamente tras activalos, senón que aparecerán após certo tempo",
    "Send notifications for events" : "Enviar notificacións para eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "As notificacións enviaranse mediante procesos en segundo plano, polo que estes teñen que suceder con frecuencia.",
    "Send reminder notifications to calendar sharees as well" : "Enviar notificacións de lembrete tamén aos que comparten calendario",
    "Reminders are always sent to organizers and attendees." : "Os lembretes envíanselle sempre aos organizadores e aos asistentes.",
    "Enable notifications for events via push" : "Activar o envío de notificacións do automáticas para eventos",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale tamén a {calendarappstoreopen}aplicación do Calendario{linkclose} ou {calendardocopen}conecte os seus escritorio e móbil para sincronizalos ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Asegúrese de ter configurado correctamente {emailopen}o servidor de correo-e{linkclose}.",
    "There was an error updating your attendance status." : "Produciuse un erro ao actualizar o seu estado de asistencia.",
    "Please contact the organizer directly." : "Contacte directamente co organizador.",
    "Are you accepting the invitation?" : "Acepta Vde. o convite?",
    "Tentative" : "Provisional",
    "Your attendance was updated successfully." : "A súa asistencia foi actualizada satisfactoriamente.",
    "To-dos" : "Tarefas pendentes",
    "Time:" : "Hora:",
    "Invalid chunk name" : "O nome do fragmento non é válido",
    "Could not rename part file assembled from chunks" : "Non foi posíbel cambiar o nome do ficheiro de pezas ensamblados a partir de fragmentos",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se configura o seu horario de traballo, outros usuarios verán cando está fóra da oficina cando reserven unha xuntanza."
},
"nplurals=2; plural=(n != 1);");
